==> haskell-temporary-1.3-735-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-2XtnvHABNGf511WcFrV1ai
key:                  temporary-1.3-2XtnvHABNGf511WcFrV1ai
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  29fd917439d6018695617d60df4f4773
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-2XtnvHABNGf511WcFrV1ai
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    random-1.2.1.3-8vZ5nHC8xeMEF0rmgzNDZj transformers-0.5.6.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-temporary-1.3-737-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-temporary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 temporary
version:              1.3
visibility:           public
id:                   temporary-1.3-GtFN5u1WRxt2XA8Ww7AlPC
key:                  temporary-1.3-GtFN5u1WRxt2XA8Ww7AlPC
license:              BSD-3-Clause
maintainer:
    Mateusz Kowalczyk <fuuzetsu@fuuzetsu.co.uk>, Roman Cheplyaka <roma@ro-che.info>

homepage:             https://github.com/feuerbach/temporary
synopsis:             Portable temporary file and directory support
description:          Functions for creating temporary files and directories.
category:             System, Utils
abi:                  59e74bb47412e9a27696c0edf98ca3a6
exposed:              True
exposed-modules:      System.IO.Temp
import-dirs:          /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs:         /usr/lib/ghc-9.4.8/site-local/temporary-1.3
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/temporary-1.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-temporary
hs-libraries:         HStemporary-1.3-GtFN5u1WRxt2XA8Ww7AlPC
depends:
    base-4.17.2.1 directory-1.3.7.1 exceptions-0.10.5 filepath-1.4.2.2
    random-1.2.1.3-7EeTCvpQeOTHIIUd77NbhG transformers-0.5.6.2
    unix-2.7.3

haddock-interfaces:   /usr/share/doc/haskell-temporary/html/temporary.haddock
haddock-html:         /usr/share/doc/haskell-temporary/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
